@@ -5,7 +5,7 @@ use warnings;
 BEGIN {
     use Exporter ();
     use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION     = '0.2_83';
+    $VERSION     = '0.2_84';
     @ISA         = qw(Exporter);
     #Give a hoot don't pollute, do not export more than needed by default
     @EXPORT      = qw();
@@ -940,7 +940,7 @@ sub processbeaconheader {
       my $myval = $val;
       unless ( $myval =~ /^\d*$/ ) {
           $myval =~ s/'/''/g;
-          $myval = "'$val'";
+          $myval = "'".$myval."'";
         };
       push(@fd, $myval);
     };
